// Fiat 126 Suspension Geometry file by mackosajt (HKV Team, www.HKV.hu)
//////////////////////////////////////////////////////////////////////////
//
// Conventions:
//
// +x = left
// +z = rear
// +y = up
// +pitch = nose up
// +yaw = nose right
// +roll = right
//
// [BODY]  - a rigid mass with mass and inertial properties
// [JOINT] - a ball joint constraining an offset of one body to an
//           offset of another body (eliminates 3 DOF)
// [HINGE] - a constraint restricting the relative rotations of two
//           bodies to be around a single axis (eliminates 2 DOF).
// [BAR]   - a constraint holding an offset of one body from an offset of
//           another body at a fixed distance (eliminates 1 DOF).
// [JOINT&HINGE] - both the joint and hinge constraints, forming the
//           conventional definition of a hinge (eliminates 5 DOF).
//
//////////////////////////////////////////////////////////////////////////

// Body including all rigidly attached parts (wings, barge boards, etc.)
[BODY]
name=body mass=(1.0) inertia=(1.0,1.0,1.0)
pos=(0.0,0.00,0.0) ori=(0.0,0.0,0.0)

// Front spindles
[BODY]
name=fl_spindle mass=(18.0) inertia=(0.0275,0.0260,0.0245)
pos=(0.550,0.0,-0.7527) ori=(0.0,0.0,0.0)

[BODY]
name=fr_spindle mass=(18.0) inertia=(0.0275,0.0260,0.0245)
pos=(-0.550,0.0,-0.7527) ori=(0.0,0.0,0.0)

// Front wheels
[BODY]
name=fl_wheel mass=(25.0) inertia=(2.250,1.000,1.000)
pos=(0.57075,0.0,-0.7527) ori=(0.0,0.0,0.0)

[BODY]
name=fr_wheel mass=(25.0) inertia=(2.250,1.000,1.000)
pos=(-0.57075,0.0,-0.7527) ori=(0.0,0.0,0.0)

// Rear spindles
[BODY]
name=rl_spindle mass=(18.0) inertia=(0.0275,0.0260,0.0245)
pos=(0.590,0.0,1.0873) ori=(0.0,0.0,0.0)

[BODY]
name=rr_spindle mass=(18.0) inertia=(0.0275,0.0260,0.0245)
pos=(-0.590,0.0,1.0873) ori=(0.0,0.0,0.0)

// Rear wheels 
[BODY]
name=rl_wheel mass=(25.0) inertia=(2.250,1.000,1.000)
pos=(0.60125,0.0,1.0873) ori=(0.0,0.0,0.0)

[BODY]
name=rr_wheel mass=(25.0) inertia=(2.250,1.000,1.000)
pos=(-0.60125,0.0,1.0873) ori=(0.0,0.0,0.0)

// Fuel in tank is not rigidly attached - it is attached with springs and
// dampers to simulate movement.  Properties are defined in the HDV file.

[BODY]
name=fuel_tank mass=(1.5) inertia=(1.0,1.0,1.0)
pos=(0.0,0.0,0.0) ori=(0.0,0.0,0.0)

// Driver's head is not rigidly attached, and it does NOT affect the vehicle
// physics.  Position is from the eyepoint defined in the VEH file, while
// other properties are defined in the head physics file.

[BODY]
name=driver_head mass=(6.0) inertia=(0.02,0.02,0.02)
pos=(0.0,0.0,0.0) ori=(0.0,0.0,0.0)


//////////////////////////////////////////////////////////////////////////
//
// Constraints
//
//////////////////////////////////////////////////////////////////////////
//Simulated Strut Suspension
// Front wheel and spindle connections
[JOINT&HINGE]
posbody=fl_wheel negbody=fl_spindle pos=fl_wheel axis=(-1.0,0.0,0.0)

[JOINT&HINGE]
posbody=fr_wheel negbody=fr_spindle pos=fr_wheel axis=(1.0,0.0,0.0)


// Front left suspension (2 A-arms + 1 steering arm = 5 links)
[BAR] // forward upper arm
name=fl_fore_upper posbody=body negbody=fl_spindle pos=(0.24, 0.07, -0.8127) neg=(0.4975, 0.05, -0.7527)

[BAR] // rearward upper arm
posbody=body negbody=fl_spindle pos=(0.24, 0.07, -0.6927) neg=(0.4975, 0.05, -0.7527)

[BAR] // forward lower arm
posbody=body negbody=fl_spindle pos=(0.195, -0.080, -0.8027) neg=(0.4875, -0.10, -0.7527)

[BAR] // rearward lower arm
name=fl_fore_lower posbody=body negbody=fl_spindle pos=(0.195, -0.080, -0.7027) neg=(0.4875, -0.10, -0.7527)

[BAR] // steering arm (must be named for identification)
name=fl_steering posbody=body negbody=fl_spindle pos=(0.2975, 0.040, -0.6100) neg=(0.530, 0.020, -0.6472)

// Front right suspension (2 A-arms + 1 steering arm = 5 links)
[BAR] // forward upper arm (used in steering lock calculation)
name=fr_fore_upper posbody=body negbody=fr_spindle pos=(-0.24, 0.07, -0.8127) neg=(-0.4975, 0.05, -0.7527)

[BAR] // rearward upper arm
posbody=body negbody=fr_spindle pos=(-0.24, 0.07, -0.6927) neg=(-0.4975, 0.05, -0.75227)

[BAR] // forward lower arm
name=fr_fore_lower posbody=body negbody=fr_spindle pos=(-0.195, -0.080, -0.8027) neg=(-0.4875,-0.10, -0.7527)

[BAR] // rearward lower arm
posbody=body negbody=fr_spindle pos=(-0.195, -0.080, -0.7027) neg=(-0.4875, -0.10,-0.7527)

[BAR] // steering arm (must be named for identification)
name=fr_steering posbody=body negbody=fr_spindle pos=(-0.2975, 0.040, -0.6100) neg=(-0.530, 0.020, -0.6472)

// Rear left suspension (2 A-arms + 1 straight link = 5 links)
[BAR] // forward upper arm
posbody=body negbody=rl_spindle pos=(0.500,0.00,0.665) neg=(0.500,-0.000,1.0873)

[BAR] // rearward upper arm
posbody=body negbody=rl_spindle pos=(0.150,0.020,1.0873) neg=(0.500,-0.000,1.0873)

[BAR] // forward lower arm
posbody=body negbody=rl_spindle pos=(0.500,-0.00,0.665) neg=(0.500,-0.085,1.0873)

[BAR] // rearward lower arm
posbody=body negbody=rl_spindle pos=(0.150,-0.055,1.0873) neg=(0.500,-0.085,1.0873)

[BAR] // straight link
posbody=body negbody=rl_spindle pos=(0.150,-0.055,1.2) neg=(0.500,-0.085,1.200)

// Rear right suspension (2 A-arms + 1 straight link = 5 links)
[BAR] // forward upper arm
posbody=body negbody=rr_spindle pos=(-0.500,0.00,0.665) neg=(-0.500,-0.000,1.0873)

[BAR] // rearward upper arm
posbody=body negbody=rr_spindle pos=(-0.150,0.020,1.0873) neg=(-0.500,-0.000,1.0873)

[BAR] // forward lower arm
posbody=body negbody=rr_spindle pos=(-0.500,-0.00,0.665) neg=(-0.500,-0.085,1.0873)

[BAR] // rearward lower arm
posbody=body negbody=rr_spindle pos=(-0.150,-0.055,1.0873) neg=(-0.500,-0.085,1.0873)

[BAR] // straight link
posbody=body negbody=rr_spindle pos=(-0.150,-0.055,1.2) neg=(-0.500,-0.085,1.20)

// Rear spindle and wheel connections 
[JOINT&HINGE]
posbody=rl_wheel negbody=rl_spindle pos=rl_wheel axis=(-1.0,0.0,0.0)

[JOINT&HINGE]
posbody=rr_wheel negbody=rr_spindle pos=rr_wheel axis=(1.0,0.0,0.0)